==> qtjambi-qt3drender-6.4.2-sources.jar: io/qt/qt3d/render/QLevelOfDetailSwitch.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a way of enabling child entities based on distance or screen size</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qlevelofdetailswitch.html">Qt3DRender::QLevelOfDetailSwitch</a></p>
 */
public class QLevelOfDetailSwitch extends io.qt.qt3d.render.QLevelOfDetail
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLevelOfDetailSwitch.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLevelOfDetailSwitch(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLevelOfDetailSwitch() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlevelofdetailswitch.html#QLevelOfDetailSwitch">Qt3DRender::QLevelOfDetailSwitch::QLevelOfDetailSwitch(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLevelOfDetailSwitch(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLevelOfDetailSwitch instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLevelOfDetailSwitch(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLevelOfDetailSwitch(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLevelOfDetailSwitch instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QLevelOfDetailSwitch.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Provides a way of enabling child entities based on distance or screen size</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qlevelofdetailswitch.html">Qt3DRender::QLevelOfDetailSwitch</a></p>
 */
public class QLevelOfDetailSwitch extends io.qt.qt3d.render.QLevelOfDetail
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLevelOfDetailSwitch.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QLevelOfDetailSwitch(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLevelOfDetailSwitch() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qlevelofdetailswitch.html#QLevelOfDetailSwitch">Qt3DRender::QLevelOfDetailSwitch::QLevelOfDetailSwitch(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLevelOfDetailSwitch(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLevelOfDetailSwitch instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QLevelOfDetailSwitch(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QLevelOfDetailSwitch(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QLevelOfDetailSwitch instance, QDeclarativeConstructor constructor);
    
}
